# ecnunetwork
[![python3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://badge.fury.io/py/ecnunetwork)[![pypi](https://badge.fury.io/py/ecnunetwork.svg)](https://badge.fury.io/py/ecnunetwork)

A script to connect to the Internet at [East China Normal University](http://english.ecnu.edu.cn).

**Author**: Jinzhe Zeng

**Email**: jzzeng@stu.ecnu.edu.cn

## Installation

Although you cannot connect to IPv4 servers before logining, IPv6 servers are still available, so you can use pip to install.

```sh
$ pip install ecnunetwork
```

## Usage
```sh
$ network
```
